Crate tauri_plugin_video

Crate tauri_plugin_video 

Structs

Builder
Plugin builder.
NativeControlRequest
NativeLayoutRequest
NativeOpenRequest
NativePlaybackSnapshot
NativePluginDiagnostics
NativeSessionRequest
NativeTrackInfo
Video
Runtime state shared by the Rust commands on every supported platform.

Enums

Error
TrackKind

Constants

VIDEO_PLUGIN_PROTOCOL_VERSION
Version of the JavaScript-to-Rust command, payload, response, and error contract. Additive diagnostic or capability fields do not change it.

Traits

VideoExt
Extensions to Tauri managers for accessing the video plugin state from Rust.

Functions

init
Initializes the plugin with production defaults.

Type Aliases

Result